TraitsUIItem
========================================

.. currentmodule:: enaml.widgets.traitsui_item

.. autoclass:: TraitsUIItem


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_traitsui_item.QtTraitsUIItem
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_traitsui_item.QtTraitsUIItem

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_traitsui_item.WXTraitsUIItem
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_traitsui_item.WXTraitsUIItem
